==> jruby_1.7.22.orig.tar.gz: jruby-1.7.22/test/externals/ruby1.9/excludes/TestIO.rb <==
exclude :test_advise, "needs investigation"
exclude :test_autoclose, "needs investigation"
exclude :test_autoclose_false_closed_by_finalizer, "depends on GC running"
exclude :test_autoclose_true_closed_by_finalizer, "depends on GC running"
exclude :test_close_on_exec, "needs investigation"
exclude :test_close_read_security_error, "needs investigation"
exclude :test_close_security_error, "needs investigation"
exclude :test_close_write, "needs investigation"
exclude :test_close_write_security_error, "needs investigation"
exclude :test_copy_stream, "needs investigation"
exclude :test_copy_stream_dst_rbuf, "needs investigation"
exclude :test_copy_stream_rot13_to_io, "needs investigation"
exclude :test_copy_stream_rot13_to_rot13, "needs investigation"
exclude :test_copy_stream_socket, "needs investigation"
exclude :test_copy_stream_src_wbuf, "needs investigation"
exclude :test_copy_stream_strio_off, "needs investigation"
exclude :test_display, "needs investigation"
exclude :test_dup, "needs investigation"
exclude :test_dup_many, "needs investigation"
exclude :test_each_line_limit_0, "needs investigation"
exclude :test_foreach, "needs investigation"
exclude :test_gets_rs, "needs investigation"
exclude :test_inspect, "needs investigation"
exclude :test_invalid_advise, "needs investigation"
exclude :test_new_with_block, "needs investigation"
exclude :test_open_mode, "needs investigation"
exclude :test_open_pipe, "needs investigation"
exclude :test_open_redirect, "needs investigation"
exclude :test_pipe_block, "needs investigation"
exclude :test_pipe_block_close, "needs investigation"
exclude :test_print, "needs investigation"
exclude :test_putc, "needs investigation"
exclude :test_read_lock, "needs investigation"
exclude :test_readline2, "needs investigation"
exclude :test_readlines, "needs investigation"
exclude :test_readlines_limit_0, "needs investigation"
exclude :test_readpartial_lock, "needs investigation"
exclude :test_reinitialize, "needs investigation"
exclude :test_reopen, "needs investigation"
exclude :test_reopen_inherit, "needs investigation"
exclude :test_s_readlines, "needs investigation"
exclude :test_s_write, "needs investigation"
exclude :test_set_lineno, "needs investigation"
exclude :test_set_stdout, "needs investigation"
exclude :test_threaded_flush, "needs investigation"
exclude :test_ungetbyte, "needs investigation"
exclude :test_ungetc, "needs investigation"
exclude :test_ungetc2, "needs investigation"
exclude :test_uninitialized, "needs investigation"

==> jruby_1.7.26.orig.tar.gz: jruby-1.7.26/test/externals/ruby1.9/excludes/TestIO.rb <==
windows = RbConfig::CONFIG['host_os'] =~ /mswin|mingw/

exclude :test_advise, "needs investigation"
exclude :test_autoclose, "needs investigation"
exclude :test_autoclose_false_closed_by_finalizer, "depends on GC running"
exclude :test_autoclose_true_closed_by_finalizer, "depends on GC running"
exclude :test_close_on_exec, "needs investigation"
exclude :test_close_read_pipe, "needs investigation" if windows
exclude :test_close_read_security_error, "needs investigation"
exclude :test_close_security_error, "needs investigation"
exclude :test_close_write, "needs investigation"
exclude :test_close_write_security_error, "needs investigation"
exclude :test_copy_stream, "needs investigation"
exclude :test_copy_stream_dst_rbuf, "needs investigation"
exclude :test_copy_stream_rot13_to_io, "needs investigation"
exclude :test_copy_stream_rot13_to_rot13, "needs investigation"
exclude :test_copy_stream_socket, "needs investigation"
exclude :test_copy_stream_src_wbuf, "needs investigation"
exclude :test_copy_stream_fname_to_strio, "needs investigation" if windows
exclude :test_copy_stream_strio_off, "needs investigation"
exclude :test_copy_stream_strio_to_fname, "needs investigation" if windows
exclude :test_display, "needs investigation"
exclude :test_dup, "needs investigation"
exclude :test_dup_many, "needs investigation"
exclude :test_each_line_limit_0, "needs investigation"
exclude :test_foreach, "needs investigation"
exclude :test_gets_rs, "needs investigation"
exclude :test_inspect, "needs investigation"
exclude :test_invalid_advise, "needs investigation"
exclude :test_new_with_block, "needs investigation"
exclude :test_open_mode, "needs investigation"
exclude :test_open_pipe, "needs investigation"
exclude :test_open_redirect, "needs investigation"
exclude :test_pid, "needs investigation" if windows
exclude :test_pipe_block, "needs investigation"
exclude :test_pipe_block_close, "needs investigation"
exclude :test_print, "needs investigation"
exclude :test_putc, "needs investigation"
exclude :test_read_lock, "needs investigation"
exclude :test_readline2, "needs investigation"
exclude :test_readlines, "needs investigation"
exclude :test_readlines_limit_0, "needs investigation"
exclude :test_readpartial_lock, "needs investigation"
exclude :test_readpartial_pos, "needs investigation" if windows
exclude :test_reinitialize, "needs investigation"
exclude :test_reopen, "needs investigation"
exclude :test_reopen_inherit, "needs investigation"
exclude :test_s_readlines, "needs investigation"
exclude :test_s_write, "needs investigation"
exclude :test_set_lineno, "needs investigation"
exclude :test_set_stdout, "needs investigation"
exclude :test_threaded_flush, "needs investigation"
exclude :test_ungetbyte, "needs investigation"
exclude :test_ungetc, "needs investigation"
exclude :test_ungetc2, "needs investigation"
exclude :test_uninitialized, "needs investigation"
